@@ -1,5 +1,4 @@
-/* $Id: socket.h 4022 2008-03-31 06:11:07Z rra $
- *
+/*
  * Portability wrapper around <sys/socket.h> and friends.
  *
  * This header file is the equivalent of:
@@ -77,7 +76,12 @@ extern int              inet_aton(const char *, struct in_addr *);
 extern const char *     inet_ntoa(const struct in_addr);
 #endif
 #if !HAVE_INET_NTOP
-extern const char *     inet_ntop(int, const void *, char *, socklen_t);
+# ifdef _WIN32
+extern const char *     inet_ntop(int, const void *, char *, int);
+# else
+extern const char *     inet_ntop(int, const void *, char *, socklen_t)
+    __attribute__((__visibility__("hidden")));
+# endif
 #endif
 
 /*
