@@ -1,5 +1,4 @@
-/* $Id: internal.h 4030 2008-04-05 00:03:27Z rra $
- *
+/*
  * Internal support functions for the remctld daemon.
  *
  * Written by Russ Allbery <rra@stanford.edu>
@@ -50,6 +49,8 @@ struct client {
 
 /* Holds the configuration for a single command. */
 struct confline {
+    char *file;                 /* Config file name. */
+    int lineno;                 /* Config file line number. */
     struct vector *line;        /* The split configuration line. */
     char *type;                 /* Service type. */
     char *service;              /* Service name. */
@@ -74,6 +75,7 @@ void server_log_command(struct vector *, struct confline *, const char *user);
 struct config *server_config_load(const char *file);
 void server_config_free(struct config *);
 bool server_config_acl_permit(struct confline *, const char *user);
+void server_config_set_gput_file(char *file);
 
 /* Running commands. */
 void server_run_command(struct client *, struct config *, struct vector *);
