@@ -1,5 +1,4 @@
-/* $Id: remctld.c 4022 2008-03-31 06:11:07Z rra $
- *
+/*
  * The remctl server.
  *
  * Handles option parsing, network setup, and the basic processing loop of the
@@ -262,7 +261,6 @@ server_daemon(struct options *options, struct config *config,
     stmp = network_bind_ipv4("any", options->port);
     if (stmp < 0)
         sysdie("cannot create socket");
-    fdflag_close_exec(stmp, true);
     if (listen(stmp, 5) < 0)
         sysdie("error listening on socket");
 
@@ -312,6 +310,7 @@ server_daemon(struct options *options, struct config *config,
             warn("sleeping ten seconds in the hope we recover...");
             sleep(10);
         } else if (child == 0) {
+            close(stmp);
             if (sigaction(SIGCHLD, &oldsa, NULL) < 0)
                 syswarn("cannot reset SIGCHLD handler");
             server_handle_connection(s, config, creds);
