@@ -1,5 +1,4 @@
-/* $Id: network-t.c 4022 2008-03-31 06:11:07Z rra $
- *
+/*
  * network test suite.
  *
  * Copyright (c) 2004, 2005, 2006, 2007
@@ -188,7 +187,7 @@ test_all(int n, const char *source_ipv4, const char *source_ipv6)
     int *fds, count, fd, i;
     pid_t child;
     struct sockaddr_storage saddr;
-    size_t size = sizeof(saddr);
+    socklen_t size = sizeof(saddr);
 
     network_bind_all(11119, &fds, &count);
     if (count == 0)
@@ -213,8 +212,10 @@ test_all(int n, const char *source_ipv4, const char *source_ipv6)
                     sysdie("cannot getsockname");
                 if (saddr.ss_family == AF_INET)
                     client("127.0.0.1", source_ipv4);
+#ifdef HAVE_INET6
                 else if (saddr.ss_family == AF_INET6)
                     client("::1", source_ipv6);
+#endif
                 else {
                     warn("unknown socket family %d", saddr.ss_family);
                     skip_block(n, 2, "unknown socket family");
