@@ -1,11 +1,11 @@
-/* $Id: xmalloc.c 4022 2008-03-31 06:11:07Z rra $
- *
+/*
  * Test suite for xmalloc and family.
  *
- * Copyright (c) 2004, 2005, 2006
+ * Copyright 2008 Board of Trustees, Leland Stanford Jr. University
+ * Copyright 2004, 2005, 2006
  *     by Internet Systems Consortium, Inc. ("ISC")
- * Copyright (c) 1991, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
- *     2002, 2003 by The Internet Software Consortium and Rich Salz
+ * Copyright 1991, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+ *     2003 by The Internet Software Consortium and Rich Salz
  *
  * This code is derived from software contributed to the Internet Software
  * Consortium by Rich Salz.
@@ -82,20 +82,19 @@ test_realloc(size_t size)
     char *buffer;
     size_t i;
 
-    buffer = xmalloc(size / 2);
+    buffer = xmalloc(10);
     if (buffer == NULL)
         return 0;
-    if (size / 2 > 0)
-        memset(buffer, 1, size / 2);
+    memset(buffer, 1, 10);
     buffer = xrealloc(buffer, size);
     if (buffer == NULL)
         return 0;
     if (size > 0)
-        memset(buffer + size / 2, 2, size - size / 2);
-    for (i = 0; i < size / 2; i++)
+        memset(buffer + 10, 2, size - 10);
+    for (i = 0; i < 10; i++)
         if (buffer[i] != 1)
             return 0;
-    for (i = size / 2; i < size; i++)
+    for (i = 10; i < size; i++)
         if (buffer[i] != 2)
             return 0;
     free(buffer);
@@ -258,6 +257,7 @@ main(int argc, char *argv[])
     int willfail = 0;
     unsigned char code;
     struct rlimit rl;
+    void *tmp;
 
     if (argc < 3)
         die("Usage error.  Type, size, and limit must be given.");
@@ -270,27 +270,6 @@ main(int argc, char *argv[])
     if (limit == 0 && errno != 0)
         sysdie("Invalid limit");
 
-    /*
-     * If a memory limit was given and we can set memory limits, set it.
-     * Otherwise, exit 2, signalling to the driver that the test should be
-     * skipped.  We do this here rather than in the driver due to some
-     * pathological problems with Linux (setting ulimit in the shell caused
-     * the shell to die).
-     */
-    if (limit > 0) {
-#if HAVE_SETRLIMIT && defined(RLIMIT_DATA)
-        rl.rlim_cur = limit;
-        rl.rlim_max = limit;
-        if (setrlimit(RLIMIT_DATA, &rl) < 0) {
-            syswarn("Can't set data limit to %lu", (unsigned long) limit);
-            exit(2);
-        }
-#else
-        warn("Data limits aren't supported.");
-        exit(2);
-#endif
-    }
-
     /* If the code is capitalized, install our customized error handler. */
     code = argv[1][0];
     if (isupper(code)) {
@@ -304,11 +283,44 @@ main(int argc, char *argv[])
      * that the test should be skipped.
      */
     max = size;
-    if (code == 's' || code == 'n' || code == 'a' || code == 'v')
-        max *= 2;
+    if (code == 's' || code == 'n' || code == 'a' || code == 'v') {
+        max += size;
+        if (limit > 0)
+            limit += size;
+    }
     if (limit > 0 && max > limit)
         willfail = 2;
 
+    /*
+     * If a memory limit was given and we can set memory limits, set it.
+     * Otherwise, exit 2, signalling to the driver that the test should be
+     * skipped.  We do this here rather than in the driver due to some
+     * pathological problems with Linux (setting ulimit in the shell caused
+     * the shell to die).
+     */
+    if (limit > 0) {
+#if HAVE_SETRLIMIT && defined(RLIMIT_AS)
+        rl.rlim_cur = limit;
+        rl.rlim_max = limit;
+        if (setrlimit(RLIMIT_AS, &rl) < 0) {
+            syswarn("Can't set data limit to %lu", (unsigned long) limit);
+            exit(2);
+        }
+        if (size < limit || code == 'r') {
+            tmp = malloc(code == 'r' ? 10 : size);
+            if (tmp == NULL) {
+                syswarn("Can't allocate initial memory of %lu",
+                        (unsigned long) size);
+                exit(2);
+            }
+            free(tmp);
+        }
+#else
+        warn("Data limits aren't supported.");
+        exit(2);
+#endif
+    }
+
     switch (code) {
     case 'c': exit(test_calloc(size) ? willfail : 1);
     case 'm': exit(test_malloc(size) ? willfail : 1);
